@@ -3,7 +3,7 @@ package Pod::ProjectDocs;
 use strict;
 use warnings;
 
-our $VERSION = '0.47_03'; # TRIAL VERSION
+our $VERSION = '0.48_001'; # TRIAL VERSION
 
 use base qw/Class::Accessor::Fast/;
 
@@ -268,13 +268,15 @@ without creating a custom perl script.
 
 L<Pod::Parser>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Lyo Kato E<lt>lyo.kato@gmail.comE<gt>
+=over 4
 
-=head1 MAINTAINER
+=item Lyo Kato E<lt>lyo.kato@gmail.comE<gt>
 
-Martin Gruner
+=item L<Martin Gruner|https://github.com/mgruner> (current maintainer)
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
